@@ -1,4 +1,4 @@
-from .class import Calculate
+from test_override.my_class import Calculate
 
 def method_test(self, num):
     return num
